Discover Packages
danny.vn/greennode
services
common
package
Version:
v1.0.7
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: MPL-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
StructToMap converts a struct to map[string]any using its JSON tags.
type Paging struct {
Page int
Size int
}
type PortalUser struct {
ID string
}
type Project struct {
ID string
}
type Tag struct {
Key string `json:"key"`
Value string `json:"value"`
IsEdited bool `json:"isEdited,omitempty"`
}
NewTags creates a []Tag from variadic key-value string pairs.
If an odd number of strings is provided, the last value defaults to "none".
const (
HCM_03_1A_ZONE Zone = "HCM03-1A"
HCM_03_1B_ZONE Zone = "HCM03-1B"
HCM_03_1C_ZONE Zone = "HCM03-1C"
HCM_03_BKK_01_ZONE Zone = "HCM03-BKK-01"
HAN_01_1A_ZONE Zone = "HAN01-1A"
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.